"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = DetailNavBar;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _reactIntl = require("react-intl");
var _reactRouterDom = require("react-router-dom");
var _immutable = _interopRequireDefault(require("immutable"));
var _get = _interopRequireDefault(require("lodash/get"));
var _config = _interopRequireDefault(require("../../config"));
var _urlHelpers = require("../../helpers/urlHelpers");
var _DetailNavBar = _interopRequireDefault(require("../../../styles/cspace/DetailNavBar.css"));
var _Link = _interopRequireDefault(require("../../../styles/cspace/Link.css"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const propTypes = {
  params: _propTypes.default.instanceOf(_immutable.default.Map).isRequired,
  prev: _propTypes.default.shape({
    'ecm:name': _propTypes.default.string
  }),
  next: _propTypes.default.shape({
    'ecm:name': _propTypes.default.string
  })
};
const defaultProps = {
  prev: undefined,
  next: undefined
};
const messages = (0, _reactIntl.defineMessages)({
  search: {
    "id": "detailNavBar.search",
    "defaultMessage": "Return to search"
  },
  prev: {
    "id": "detailNavBar.prev",
    "defaultMessage": "Previous"
  },
  next: {
    "id": "detailNavBar.next",
    "defaultMessage": "Next"
  }
});
function DetailNavBar(props) {
  const {
    params,
    prev,
    next
  } = props;
  const index = params.get('index');
  const searchParams = params.get('searchParams');
  if (!searchParams || typeof index === 'undefined') {
    return null;
  }
  const searchParamsObj = searchParams.toJS();
  const detailPath = _config.default.get('detailPath');
  let prevLink;
  let nextLink;
  if (prev) {
    const csid = (0, _get.default)(prev, 'ecm:name');
    prevLink = /*#__PURE__*/_react.default.createElement("span", null, /*#__PURE__*/_react.default.createElement(_reactRouterDom.Link, {
      className: _Link.default.prev,
      to: {
        pathname: `/${detailPath}/${csid}`,
        state: {
          index: index - 1,
          searchParams: searchParamsObj
        }
      }
    }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.prev)));
  }
  if (next) {
    const csid = (0, _get.default)(next, 'ecm:name');
    nextLink = /*#__PURE__*/_react.default.createElement("span", null, /*#__PURE__*/_react.default.createElement(_reactRouterDom.Link, {
      className: _Link.default.next,
      to: {
        pathname: `/${detailPath}/${csid}`,
        state: {
          index: index + 1,
          searchParams: searchParamsObj
        }
      }
    }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.next)));
  }
  const queryString = (0, _urlHelpers.searchParamsToQueryString)(searchParams);
  return /*#__PURE__*/_react.default.createElement("nav", {
    className: _DetailNavBar.default.common
  }, /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_reactRouterDom.Link, {
    className: _Link.default.back,
    to: {
      pathname: '/search',
      search: `?${queryString}`
    }
  }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.search))), /*#__PURE__*/_react.default.createElement("div", null, prevLink, nextLink));
}
DetailNavBar.propTypes = propTypes;
DetailNavBar.defaultProps = defaultProps;