"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _reactIntl = require("react-intl");
var _reactRouter = require("react-router");
var _immutable = _interopRequireDefault(require("immutable"));
var _memoizeOne = _interopRequireDefault(require("memoize-one"));
var _FilterSearchInput = _interopRequireDefault(require("./FilterSearchInput"));
var _PanelContainer = _interopRequireDefault(require("../../layout/PanelContainer"));
var _Filter = _interopRequireDefault(require("../../../../styles/cspace/Filter.css"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const propTypes = {
  aggregation: _propTypes.default.instanceOf(_immutable.default.Map),
  field: _propTypes.default.string.isRequired,
  formatValue: _propTypes.default.func,
  history: _propTypes.default.shape({
    push: _propTypes.default.func.isRequired
  }).isRequired,
  id: _propTypes.default.string.isRequired,
  messages: _propTypes.default.shape({
    label: _propTypes.default.object.isRequired
  }).isRequired,
  onSearchValueCommit: _propTypes.default.func,
  onValueCommit: _propTypes.default.func,
  params: _propTypes.default.instanceOf(_immutable.default.Map).isRequired,
  searchValue: _propTypes.default.string,
  showSearch: _propTypes.default.bool
};
const defaultProps = {
  aggregation: _immutable.default.Map(),
  formatValue: undefined,
  onSearchValueCommit: () => undefined,
  onValueCommit: () => undefined,
  searchValue: undefined,
  showSearch: true
};
const messages = (0, _reactIntl.defineMessages)({
  count: {
    "id": "filter.count",
    "defaultMessage": "({count, number})"
  }
});
const getFormattedValues = (0, _memoizeOne.default)((aggregation, formatValue) => {
  if (!formatValue) {
    return undefined;
  }
  const formattedValues = {};
  aggregation.get('buckets').forEach(bucket => {
    const value = bucket.get('key');
    const formattedValue = formatValue(value);
    formattedValues[value] = formattedValue;
  });
  return formattedValues;
});
const handleCheckboxFocus = event => {
  const {
    target: focusedFieldElement
  } = event;
  const fieldIndex = focusedFieldElement.getAttribute('data-number');
  const focusedFieldLiElement = focusedFieldElement.parentElement.parentElement;
  const focusedFieldUlElement = focusedFieldLiElement.parentElement;
  const newScrollPosition = focusedFieldLiElement.getBoundingClientRect().height * fieldIndex;
  focusedFieldUlElement.scrollTop = newScrollPosition;
  focusedFieldUlElement.scrollIntoView({
    block: 'end',
    behavior: 'instant'
  });
};
class Filter extends _react.Component {
  constructor() {
    super();
    this.handleCheckboxChange = this.handleCheckboxChange.bind(this);
    this.handleSearchInputCommit = this.handleSearchInputCommit.bind(this);
  }
  handleSearchInputCommit(value) {
    const {
      id,
      onSearchValueCommit
    } = this.props;
    onSearchValueCommit(id, value);
  }
  handleCheckboxChange(event) {
    const {
      history,
      id,
      onValueCommit
    } = this.props;
    const {
      target: checkbox
    } = event;
    const {
      dataset,
      name
    } = checkbox;
    const {
      type
    } = dataset;
    const value = type === 'number' ? Number.parseInt(name, 10) : name;
    onValueCommit(history, id, value, checkbox.checked);
  }
  renderBuckets() {
    const {
      aggregation,
      formatValue,
      id,
      params,
      searchValue
    } = this.props;
    const formattedValues = getFormattedValues(aggregation, formatValue);
    const buckets = aggregation.get('buckets');
    let matchingBuckets = buckets;
    if (searchValue) {
      const needle = searchValue.toLowerCase();
      matchingBuckets = buckets.filter(bucket => {
        const value = bucket.get('key');
        const formattedValue = formattedValues ? formattedValues[value] : value;
        const haystack = formattedValue.toLowerCase();
        return haystack.includes(needle);
      });
    }
    let selectedValues = params.get(id) || _immutable.default.List();
    if (!_immutable.default.List.isList(selectedValues)) {
      selectedValues = _immutable.default.List.of(selectedValues);
    }
    return matchingBuckets.map((bucket, index) => {
      const value = bucket.get('key');
      const type = typeof value;
      const count = bucket.get('doc_count');
      const isSelected = selectedValues.indexOf(value) >= 0;
      const formattedValue = formattedValues ? formattedValues[value] : value;
      return /*#__PURE__*/_react.default.createElement("li", {
        key: value
      }, /*#__PURE__*/_react.default.createElement("label", null, /*#__PURE__*/_react.default.createElement("input", {
        checked: isSelected,
        "data-type": type !== 'string' ? type : undefined,
        "data-number": index,
        name: value,
        type: "checkbox",
        onChange: this.handleCheckboxChange,
        onFocus: handleCheckboxFocus
      }), /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement("span", null, formattedValue, ' ', /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.count, {
        values: {
          count
        }
      }))))));
    });
  }
  render() {
    const {
      aggregation,
      id,
      messages: filterMessages,
      searchValue,
      showSearch
    } = this.props;
    const buckets = aggregation.get('buckets');
    const isEmpty = !buckets || buckets.size === 0;
    if (isEmpty) {
      return null;
    }

    // eslint-disable-next-line react/jsx-props-no-spreading
    const title = /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, filterMessages.label);
    return /*#__PURE__*/_react.default.createElement(_PanelContainer.default, {
      id: `Filter-${id}`,
      title: title
    }, /*#__PURE__*/_react.default.createElement("div", {
      className: _Filter.default.common
    }, showSearch && /*#__PURE__*/_react.default.createElement(_FilterSearchInput.default, {
      value: searchValue,
      onCommit: this.handleSearchInputCommit
    }), /*#__PURE__*/_react.default.createElement("ul", null, this.renderBuckets(buckets))));
  }
}
Filter.propTypes = propTypes;
Filter.defaultProps = defaultProps;
var _default = (0, _reactRouter.withRouter)(Filter);
exports.default = _default;