"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _reactIntl = require("react-intl");
var _immutable = _interopRequireDefault(require("immutable"));
var _FilterList = _interopRequireDefault(require("./FilterList"));
var _config = _interopRequireDefault(require("../../../config"));
var _FilterPanel = _interopRequireDefault(require("../../../../styles/cspace/FilterPanel.css"));
var _dimensions = _interopRequireDefault(require("../../../../styles/dimensions.css"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
/* global window */

const propTypes = {
  api: _propTypes.default.func,
  isExpanded: _propTypes.default.bool,
  isPending: _propTypes.default.bool,
  result: _propTypes.default.instanceOf(_immutable.default.Map)
};
const defaultProps = {
  api: () => undefined,
  isExpanded: false,
  isPending: false,
  result: _immutable.default.Map()
};
const messages = (0, _reactIntl.defineMessages)({
  title: {
    "id": "FilterPanel.title",
    "defaultMessage": "Refine results:"
  }
});
const {
  filterPanelCutoffWidth: cssFilterPanelCutoffWidth
} = _dimensions.default;
const filterPanelCutoffWidth = parseInt(cssFilterPanelCutoffWidth, 10);
class FilterPanel extends _react.Component {
  constructor() {
    super();
    this.handleResize = this.handleResize.bind(this);
    this.handleScroll = this.handleScroll.bind(this);
    this.ref = /*#__PURE__*/_react.default.createRef();
    this.state = {};
  }
  componentDidMount() {
    const {
      api
    } = this.props;
    window.addEventListener('resize', this.handleResize);
    window.addEventListener('scroll', this.handleScroll);
    api({
      setHeight: this.setHeight.bind(this)
    });
    this.setHeight();
  }
  componentWillUnmount() {
    window.removeEventListener('resize', this.handleResize);
    window.removeEventListener('scroll', this.handleScroll);
  }
  handleResize() {
    this.setHeight();
  }
  handleScroll() {
    this.setHeight();
  }
  setHeight() {
    const height = window.innerHeight;
    const rect = this.ref.current.getBoundingClientRect();
    const maxHeight = height - rect.top;
    this.setState({
      height: maxHeight
    });
  }
  renderContent() {
    const {
      isExpanded,
      isPending,
      result
    } = this.props;
    const isVisible = window.innerWidth > filterPanelCutoffWidth || isExpanded;
    if (!isVisible || !result.get('total')) {
      return undefined;
    }
    return /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement("header", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.title)), /*#__PURE__*/_react.default.createElement(_FilterList.default, {
      aggregations: result.get('aggregations'),
      config: _config.default.get('filters'),
      isPending: isPending
    }));
  }
  render() {
    const {
      isExpanded
    } = this.props;
    const {
      height
    } = this.state;
    const className = isExpanded ? _FilterPanel.default.expanded : _FilterPanel.default.collapsed;
    const inlineStyle = height ? {
      height
    } : undefined;
    return /*#__PURE__*/_react.default.createElement("div", {
      className: className,
      ref: this.ref,
      style: inlineStyle
    }, this.renderContent());
  }
}
exports.default = FilterPanel;
FilterPanel.propTypes = propTypes;
FilterPanel.defaultProps = defaultProps;