"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _immutable = _interopRequireDefault(require("immutable"));
var _reactIntl = require("react-intl");
var _SearchError = _interopRequireDefault(require("./SearchError"));
var _SearchLoadMore = _interopRequireDefault(require("./SearchLoadMore"));
var _SearchPending = _interopRequireDefault(require("./SearchPending"));
var _SearchResultTile = _interopRequireDefault(require("./SearchResultTile"));
var _config = _interopRequireDefault(require("../../../config"));
var _searchDimensions = require("../../../helpers/searchDimensions");
var _SearchResultList = _interopRequireDefault(require("../../../../styles/cspace/SearchResultList.css"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const propTypes = {
  error: _propTypes.default.instanceOf(Error),
  hits: _propTypes.default.instanceOf(_immutable.default.List),
  isPending: _propTypes.default.bool,
  onHitsUpdated: _propTypes.default.func,
  onLoadMoreClick: _propTypes.default.func,
  params: _propTypes.default.instanceOf(_immutable.default.Map).isRequired,
  showLoadMore: _propTypes.default.bool
};
const defaultProps = {
  error: undefined,
  hits: _immutable.default.List(),
  isPending: false,
  onHitsUpdated: () => undefined,
  onLoadMoreClick: () => undefined,
  showLoadMore: false
};
const messages = (0, _reactIntl.defineMessages)({
  noResult: {
    "id": "searchResultList.noResult",
    "defaultMessage": "No results found"
  }
});
class SearchResultList extends _react.Component {
  componentDidUpdate(prevProps) {
    const {
      hits,
      onHitsUpdated
    } = this.props;
    const {
      hits: prevHits
    } = prevProps;
    if (hits !== prevHits) {
      onHitsUpdated();
    }
  }
  renderError() {
    const {
      error
    } = this.props;
    if (!error) {
      return undefined;
    }
    return /*#__PURE__*/_react.default.createElement(_SearchError.default, {
      error: error
    });
  }
  renderLoadMore() {
    const {
      isPending,
      onLoadMoreClick,
      showLoadMore
    } = this.props;
    if (!showLoadMore || isPending) {
      return undefined;
    }
    return /*#__PURE__*/_react.default.createElement(_SearchLoadMore.default, {
      onClick: onLoadMoreClick
    });
  }
  renderPending() {
    const {
      isPending
    } = this.props;
    if (!isPending) {
      return undefined;
    }
    return /*#__PURE__*/_react.default.createElement(_SearchPending.default, null);
  }
  renderHits() {
    const {
      error,
      params,
      hits,
      isPending
    } = this.props;
    if (hits.size === 0 && !isPending && !error) {
      return /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.noResult));
    }
    const gatewayUrl = _config.default.get('gatewayUrl');
    const pageSize = (0, _searchDimensions.calculateSearchPageSize)();
    return hits.map((result, index) => /*#__PURE__*/_react.default.createElement(_SearchResultTile.default, {
      gatewayUrl: gatewayUrl,
      loadImageImmediately: index < pageSize,
      index: index,
      key: result.getIn(['_source', 'ecm:name']),
      params: params,
      result: result
    }));
  }
  render() {
    return /*#__PURE__*/_react.default.createElement("div", {
      className: _SearchResultList.default.common
    }, this.renderHits(), this.renderLoadMore(), this.renderPending(), this.renderError());
  }
}
exports.default = SearchResultList;
SearchResultList.propTypes = propTypes;
SearchResultList.defaultProps = defaultProps;