"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _immutable = _interopRequireDefault(require("immutable"));
var _SearchParamList = _interopRequireDefault(require("./SearchParamList"));
var _SearchResultList = _interopRequireDefault(require("./SearchResultList"));
var _SearchResultStats = _interopRequireDefault(require("./SearchResultStats"));
var _SortSelectContainer = _interopRequireDefault(require("../entry/SortSelectContainer"));
var _config = _interopRequireDefault(require("../../../config"));
var _ids = require("../../../constants/ids");
var _searchDimensions = require("../../../helpers/searchDimensions");
var _SearchResultPanel = _interopRequireDefault(require("../../../../styles/cspace/SearchResultPanel.css"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
/* global window */

const propTypes = {
  error: _propTypes.default.instanceOf(Error),
  isPending: _propTypes.default.bool,
  nextOffset: _propTypes.default.number,
  onHitsUpdated: _propTypes.default.func,
  result: _propTypes.default.instanceOf(_immutable.default.Map),
  params: _propTypes.default.instanceOf(_immutable.default.Map),
  search: _propTypes.default.func,
  setSearchPageSize: _propTypes.default.func
};
const defaultProps = {
  error: undefined,
  isPending: false,
  nextOffset: undefined,
  onHitsUpdated: undefined,
  params: _immutable.default.Map(),
  result: undefined,
  search: () => undefined,
  setSearchPageSize: () => undefined
};
class SearchResultPanel extends _react.Component {
  constructor() {
    super();
    this.handleLoadMoreClick = this.handleLoadMoreClick.bind(this);
    this.handleScroll = this.handleScroll.bind(this);
    this.ref = /*#__PURE__*/_react.default.createRef();
  }
  componentDidMount() {
    const {
      setSearchPageSize
    } = this.props;
    window.addEventListener('scroll', this.handleScroll, false);
    setSearchPageSize((0, _searchDimensions.calculateSearchPageSize)());
    this.search();
  }
  componentDidUpdate(prevProps) {
    const {
      params
    } = this.props;
    const {
      params: prevParams
    } = prevProps;
    if (params !== prevParams) {
      this.search();
    }
  }
  componentWillUnmount() {
    window.removeEventListener('scroll', this.handleScroll, false);
  }
  handleLoadMoreClick() {
    this.search();
  }
  handleScroll() {
    const {
      nextOffset
    } = this.props;
    if (nextOffset < _config.default.get('pageAutoLoadLimit')) {
      const {
        search
      } = this.props;
      const rect = this.ref.current.getBoundingClientRect();
      const bottomOffset = rect.bottom - window.innerHeight;
      if (bottomOffset <= _searchDimensions.tileHeight) {
        search(_config.default.get('pageLoadDelay'));
      }
    }
  }
  search(fetchDelay) {
    const {
      search
    } = this.props;
    search(fetchDelay);
  }
  renderError() {
    const {
      error
    } = this.props;
    return /*#__PURE__*/_react.default.createElement("div", null, error.message);
  }
  renderResult() {
    const {
      error,
      isPending,
      nextOffset,
      onHitsUpdated,
      params,
      result
    } = this.props;
    const hitCount = result && result.get('total');
    const hits = result && result.get('hits');
    const showLoadMore = result && hits.size < hitCount && nextOffset >= _config.default.get('pageAutoLoadLimit');
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("header", null, /*#__PURE__*/_react.default.createElement(_SearchParamList.default, {
      params: params
    }), /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_SearchResultStats.default, {
      count: hitCount
    }), /*#__PURE__*/_react.default.createElement(_SortSelectContainer.default, {
      value: params.get(_ids.SORT_ID)
    }))), /*#__PURE__*/_react.default.createElement(_SearchResultList.default, {
      error: error,
      isPending: isPending,
      onHitsUpdated: onHitsUpdated,
      onLoadMoreClick: this.handleLoadMoreClick,
      params: params,
      hits: hits,
      showLoadMore: showLoadMore
    }));
  }
  render() {
    return /*#__PURE__*/_react.default.createElement("div", {
      className: _SearchResultPanel.default.common,
      ref: this.ref
    }, this.renderResult());
  }
}
exports.default = SearchResultPanel;
SearchResultPanel.propTypes = propTypes;
SearchResultPanel.defaultProps = defaultProps;